@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Base;
 
-our $DATE = '2015-06-11'; # DATE
-our $VERSION = '1.14'; # VERSION
+our $DATE = '2015-06-19'; # DATE
+our $VERSION = '1.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -608,7 +608,7 @@ sub _parse_argv1 {
 
         require Getopt::Long;
         my $old_go_conf = Getopt::Long::Configure(
-            'pass_through', 'permute', 'no_ignore_case', 'no_auto_abbrev');
+            'pass_through', 'no_ignore_case', 'bundling', 'no_auto_abbrev');
         my @go_spec;
         my $co = $self->common_opts // {};
         for my $k (keys %$co) {
@@ -1191,8 +1191,14 @@ sub run {
     my $err = $@;
     if ($err || !$r->{res}) {
         if ($err) {
-            $err =~ s/\n+$//;
             $err = [500, "Died: $err"] unless ref($err) eq 'ARRAY';
+            require Scalar::Util;
+            if (%Devel::Confess::) {
+                my $id = Scalar::Util::refaddr($err);
+                my $stack_trace = $Devel::Confess::MESSAGES{$id};
+                $err->[1] .= "\n$stack_trace" if $stack_trace;
+            }
+            $err->[1] =~ s/\n+$//;
             $r->{res} = $err;
         } else {
             $r->{res} = [500, "Bug: no response produced"];
@@ -1266,7 +1272,7 @@ Perinci::CmdLine::Base - Base class for Perinci::CmdLine{::Classic,::Lite}
 
 =head1 VERSION
 
-This document describes version 1.14 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-11.
+This document describes version 1.15 of Perinci::CmdLine::Base (from Perl distribution Perinci-CmdLine-Lite), released on 2015-06-19.
 
 =head1 DESCRIPTION
 
